from skepticoin.__version__ import __version__


def main() -> None:
    print(__version__)
